# IBLPy

IBLPy is a API wrapper/library around [Infinity Bot List](https://infinitybots.xyz), which is a great novel bot list for the next generation of bots owned by ``☣ Tσxιƈ Dҽʋ ☣#7308``. See [here](https://iblpy.bristleroot.me) for docs

## Issues And Contributing

This API wrapper/library is maintained by ``Rootspring#6701``. If you wish to contribute to this project or report an issue, please make a Github Issue or a Pull Request (templates coming soon)
